{ "CAN_INLUDE_BOTH_sys_types_h_AND_linux_types_h",
#ifdef CAN_INLUDE_BOTH_sys_types_h_AND_linux_types_h
1
#else
0
#endif
},
{ "CONF_NAME_MAX",
#ifdef CONF_NAME_MAX
1
#else
0
#endif
},
{ "CONF_SHELL",
#ifdef CONF_SHELL
1
#else
0
#endif
},
{ "GETMNTENT_NARGS",
#ifdef GETMNTENT_NARGS
1
#else
0
#endif
},
{ "GETPGRP_NARGS",
#ifdef GETPGRP_NARGS
1
#else
0
#endif
},
{ "HAVE_ACCEPT4",
#ifdef HAVE_ACCEPT4
1
#else
0
#endif
},
{ "HAVE_ADJTIMEX",
#ifdef HAVE_ADJTIMEX
1
#else
0
#endif
},
{ "HAVE_ARPA_INET_H",
#ifdef HAVE_ARPA_INET_H
1
#else
0
#endif
},
{ "HAVE_ATEXIT",
#ifdef HAVE_ATEXIT
1
#else
0
#endif
},
{ "HAVE_BLUETOOTH_BLUETOOTH_H",
#ifdef HAVE_BLUETOOTH_BLUETOOTH_H
1
#else
0
#endif
},
{ "HAVE_BLUETOOTH_BNEP_H",
#ifdef HAVE_BLUETOOTH_BNEP_H
1
#else
0
#endif
},
{ "HAVE_BLUETOOTH_CMTP_H",
#ifdef HAVE_BLUETOOTH_CMTP_H
1
#else
0
#endif
},
{ "HAVE_BLUETOOTH_HCI_H",
#ifdef HAVE_BLUETOOTH_HCI_H
1
#else
0
#endif
},
{ "HAVE_BLUETOOTH_HIDP_H",
#ifdef HAVE_BLUETOOTH_HIDP_H
1
#else
0
#endif
},
{ "HAVE_BLUETOOTH_RFCOMM_H",
#ifdef HAVE_BLUETOOTH_RFCOMM_H
1
#else
0
#endif
},
{ "HAVE_CAPGET",
#ifdef HAVE_CAPGET
1
#else
0
#endif
},
{ "HAVE_CAP_GET_PROC",
#ifdef HAVE_CAP_GET_PROC
1
#else
0
#endif
},
{ "HAVE_CFMAKERAW",
#ifdef HAVE_CFMAKERAW
1
#else
0
#endif
},
{ "HAVE_DECL_STRERROR_R",
#ifdef HAVE_DECL_STRERROR_R
1
#else
0
#endif
},
{ "HAVE_DECL_STRSIGNAL",
#ifdef HAVE_DECL_STRSIGNAL
1
#else
0
#endif
},
{ "HAVE_DECL_STRVERSCMP",
#ifdef HAVE_DECL_STRVERSCMP
1
#else
0
#endif
},
{ "HAVE_DECL_USTAT",
#ifdef HAVE_DECL_USTAT
1
#else
0
#endif
},
{ "HAVE_DIRENT_H",
#ifdef HAVE_DIRENT_H
1
#else
0
#endif
},
{ "HAVE_DIRFD",
#ifdef HAVE_DIRFD
1
#else
0
#endif
},
{ "HAVE_DLADDR",
#ifdef HAVE_DLADDR
1
#else
0
#endif
},
{ "HAVE_DLFCN_H",
#ifdef HAVE_DLFCN_H
1
#else
0
#endif
},
{ "HAVE_DLSYM",
#ifdef HAVE_DLSYM
1
#else
0
#endif
},
{ "HAVE_ENDMNTENT",
#ifdef HAVE_ENDMNTENT
1
#else
0
#endif
},
{ "HAVE_EVENTFD",
#ifdef HAVE_EVENTFD
1
#else
0
#endif
},
{ "HAVE_FCNTL_H",
#ifdef HAVE_FCNTL_H
1
#else
0
#endif
},
{ "HAVE_FDOPENDIR",
#ifdef HAVE_FDOPENDIR
1
#else
0
#endif
},
{ "HAVE_FLOAT_H",
#ifdef HAVE_FLOAT_H
1
#else
0
#endif
},
{ "HAVE_FLOCK",
#ifdef HAVE_FLOCK
1
#else
0
#endif
},
{ "HAVE_FPURGE",
#ifdef HAVE_FPURGE
1
#else
0
#endif
},
{ "HAVE_FSEEKO",
#ifdef HAVE_FSEEKO
1
#else
0
#endif
},
{ "HAVE_FSTATFS",
#ifdef HAVE_FSTATFS
1
#else
0
#endif
},
{ "HAVE_FTIME",
#ifdef HAVE_FTIME
1
#else
0
#endif
},
{ "HAVE_FUTIMES",
#ifdef HAVE_FUTIMES
1
#else
0
#endif
},
{ "HAVE_GETDOMAINNAME",
#ifdef HAVE_GETDOMAINNAME
1
#else
0
#endif
},
{ "HAVE_GETHOSTNAME",
#ifdef HAVE_GETHOSTNAME
1
#else
0
#endif
},
{ "HAVE_GETMNTENT",
#ifdef HAVE_GETMNTENT
1
#else
0
#endif
},
{ "HAVE_GETMNTINFO",
#ifdef HAVE_GETMNTINFO
1
#else
0
#endif
},
{ "HAVE_GETOPT_H",
#ifdef HAVE_GETOPT_H
1
#else
0
#endif
},
{ "HAVE_GETOPT_LONG",
#ifdef HAVE_GETOPT_LONG
1
#else
0
#endif
},
{ "HAVE_GETPAGESIZE",
#ifdef HAVE_GETPAGESIZE
1
#else
0
#endif
},
{ "HAVE_GETTEXT",
#ifdef HAVE_GETTEXT
1
#else
0
#endif
},
{ "HAVE_HASMNTOPT",
#ifdef HAVE_HASMNTOPT
1
#else
0
#endif
},
{ "HAVE_INLINE",
#ifdef HAVE_INLINE
1
#else
0
#endif
},
{ "HAVE_INTTYPES_H",
#ifdef HAVE_INTTYPES_H
1
#else
0
#endif
},
{ "HAVE_LCHOWN",
#ifdef HAVE_LCHOWN
1
#else
0
#endif
},
{ "HAVE_LIBGETTEXT",
#ifdef HAVE_LIBGETTEXT
1
#else
0
#endif
},
{ "HAVE_LIBICONV",
#ifdef HAVE_LIBICONV
1
#else
0
#endif
},
{ "HAVE_LIBINTL",
#ifdef HAVE_LIBINTL
1
#else
0
#endif
},
{ "HAVE_LIBINTL_H",
#ifdef HAVE_LIBINTL_H
1
#else
0
#endif
},
{ "HAVE_LIBIO_H",
#ifdef HAVE_LIBIO_H
1
#else
0
#endif
},
{ "HAVE_LIBSOCKET",
#ifdef HAVE_LIBSOCKET
1
#else
0
#endif
},
{ "HAVE_LIBV4L1_VIDEODEV_H",
#ifdef HAVE_LIBV4L1_VIDEODEV_H
1
#else
0
#endif
},
{ "HAVE_LIMITS_H",
#ifdef HAVE_LIMITS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_APM_BIOS_H",
#ifdef HAVE_LINUX_APM_BIOS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ARCFB_H",
#ifdef HAVE_LINUX_ARCFB_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATALK_H",
#ifdef HAVE_LINUX_ATALK_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATA_H",
#ifdef HAVE_LINUX_ATA_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATMARP_H",
#ifdef HAVE_LINUX_ATMARP_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATMBR2684_H",
#ifdef HAVE_LINUX_ATMBR2684_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATMCLIP_H",
#ifdef HAVE_LINUX_ATMCLIP_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATMDEV_H",
#ifdef HAVE_LINUX_ATMDEV_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATMLEC_H",
#ifdef HAVE_LINUX_ATMLEC_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATMMPC_H",
#ifdef HAVE_LINUX_ATMMPC_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATMSVC_H",
#ifdef HAVE_LINUX_ATMSVC_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATM_ENI_H",
#ifdef HAVE_LINUX_ATM_ENI_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATM_H",
#ifdef HAVE_LINUX_ATM_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATM_HE_H",
#ifdef HAVE_LINUX_ATM_HE_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATM_IDT77105_H",
#ifdef HAVE_LINUX_ATM_IDT77105_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATM_NICSTAR_H",
#ifdef HAVE_LINUX_ATM_NICSTAR_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATM_TCP_H",
#ifdef HAVE_LINUX_ATM_TCP_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ATM_ZATM_H",
#ifdef HAVE_LINUX_ATM_ZATM_H
1
#else
0
#endif
},
{ "HAVE_LINUX_AUTO_FS4_H",
#ifdef HAVE_LINUX_AUTO_FS4_H
1
#else
0
#endif
},
{ "HAVE_LINUX_AUTO_FS_H",
#ifdef HAVE_LINUX_AUTO_FS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_BLKPG_H",
#ifdef HAVE_LINUX_BLKPG_H
1
#else
0
#endif
},
{ "HAVE_LINUX_BLKTRACE_API_H",
#ifdef HAVE_LINUX_BLKTRACE_API_H
1
#else
0
#endif
},
{ "HAVE_LINUX_CAPI_H",
#ifdef HAVE_LINUX_CAPI_H
1
#else
0
#endif
},
{ "HAVE_LINUX_CCISS_IOCTL_H",
#ifdef HAVE_LINUX_CCISS_IOCTL_H
1
#else
0
#endif
},
{ "HAVE_LINUX_CDK_H",
#ifdef HAVE_LINUX_CDK_H
1
#else
0
#endif
},
{ "HAVE_LINUX_CDROM_H",
#ifdef HAVE_LINUX_CDROM_H
1
#else
0
#endif
},
{ "HAVE_LINUX_CHIO_H",
#ifdef HAVE_LINUX_CHIO_H
1
#else
0
#endif
},
{ "HAVE_LINUX_CM206_H",
#ifdef HAVE_LINUX_CM206_H
1
#else
0
#endif
},
{ "HAVE_LINUX_CM4000_CS_H",
#ifdef HAVE_LINUX_CM4000_CS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_COMSTATS_H",
#ifdef HAVE_LINUX_COMSTATS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_CYCLADES_H",
#ifdef HAVE_LINUX_CYCLADES_H
1
#else
0
#endif
},
{ "HAVE_LINUX_DN_H",
#ifdef HAVE_LINUX_DN_H
1
#else
0
#endif
},
{ "HAVE_LINUX_DVB_AUDIO_H",
#ifdef HAVE_LINUX_DVB_AUDIO_H
1
#else
0
#endif
},
{ "HAVE_LINUX_DVB_CA_H",
#ifdef HAVE_LINUX_DVB_CA_H
1
#else
0
#endif
},
{ "HAVE_LINUX_DVB_DMX_H",
#ifdef HAVE_LINUX_DVB_DMX_H
1
#else
0
#endif
},
{ "HAVE_LINUX_DVB_FRONTEND_H",
#ifdef HAVE_LINUX_DVB_FRONTEND_H
1
#else
0
#endif
},
{ "HAVE_LINUX_DVB_NET_H",
#ifdef HAVE_LINUX_DVB_NET_H
1
#else
0
#endif
},
{ "HAVE_LINUX_DVB_OSD_H",
#ifdef HAVE_LINUX_DVB_OSD_H
1
#else
0
#endif
},
{ "HAVE_LINUX_DVB_VIDEO_H",
#ifdef HAVE_LINUX_DVB_VIDEO_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ETHTOOL_H",
#ifdef HAVE_LINUX_ETHTOOL_H
1
#else
0
#endif
},
{ "HAVE_LINUX_EXT2_FS_H",
#ifdef HAVE_LINUX_EXT2_FS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_FB_H",
#ifdef HAVE_LINUX_FB_H
1
#else
0
#endif
},
{ "HAVE_LINUX_FCNTL_H",
#ifdef HAVE_LINUX_FCNTL_H
1
#else
0
#endif
},
{ "HAVE_LINUX_FD_H",
#ifdef HAVE_LINUX_FD_H
1
#else
0
#endif
},
{ "HAVE_LINUX_FIEMAP_H",
#ifdef HAVE_LINUX_FIEMAP_H
1
#else
0
#endif
},
{ "HAVE_LINUX_FILTER_H",
#ifdef HAVE_LINUX_FILTER_H
1
#else
0
#endif
},
{ "HAVE_LINUX_FIREWIRE_CDEV_H",
#ifdef HAVE_LINUX_FIREWIRE_CDEV_H
1
#else
0
#endif
},
{ "HAVE_LINUX_FS_H",
#ifdef HAVE_LINUX_FS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_HAYESESP_H",
#ifdef HAVE_LINUX_HAYESESP_H
1
#else
0
#endif
},
{ "HAVE_LINUX_HDREG_H",
#ifdef HAVE_LINUX_HDREG_H
1
#else
0
#endif
},
{ "HAVE_LINUX_HIDDEV_H",
#ifdef HAVE_LINUX_HIDDEV_H
1
#else
0
#endif
},
{ "HAVE_LINUX_HIDRAW_H",
#ifdef HAVE_LINUX_HIDRAW_H
1
#else
0
#endif
},
{ "HAVE_LINUX_HPET_H",
#ifdef HAVE_LINUX_HPET_H
1
#else
0
#endif
},
{ "HAVE_LINUX_I2O_DEV_H",
#ifdef HAVE_LINUX_I2O_DEV_H
1
#else
0
#endif
},
{ "HAVE_LINUX_IF_BONDING_H",
#ifdef HAVE_LINUX_IF_BONDING_H
1
#else
0
#endif
},
{ "HAVE_LINUX_IF_BRIDGE_H",
#ifdef HAVE_LINUX_IF_BRIDGE_H
1
#else
0
#endif
},
{ "HAVE_LINUX_IF_EQL_H",
#ifdef HAVE_LINUX_IF_EQL_H
1
#else
0
#endif
},
{ "HAVE_LINUX_IF_FRAD_H",
#ifdef HAVE_LINUX_IF_FRAD_H
1
#else
0
#endif
},
{ "HAVE_LINUX_IF_H",
#ifdef HAVE_LINUX_IF_H
1
#else
0
#endif
},
{ "HAVE_LINUX_IF_PPPOX_H",
#ifdef HAVE_LINUX_IF_PPPOX_H
1
#else
0
#endif
},
{ "HAVE_LINUX_IF_PPP_H",
#ifdef HAVE_LINUX_IF_PPP_H
1
#else
0
#endif
},
{ "HAVE_LINUX_IF_TUN_H",
#ifdef HAVE_LINUX_IF_TUN_H
1
#else
0
#endif
},
{ "HAVE_LINUX_IF_VLAN_H",
#ifdef HAVE_LINUX_IF_VLAN_H
1
#else
0
#endif
},
{ "HAVE_LINUX_INPUT_H",
#ifdef HAVE_LINUX_INPUT_H
1
#else
0
#endif
},
{ "HAVE_LINUX_IPMI_H",
#ifdef HAVE_LINUX_IPMI_H
1
#else
0
#endif
},
{ "HAVE_LINUX_IPV6_H",
#ifdef HAVE_LINUX_IPV6_H
1
#else
0
#endif
},
{ "HAVE_LINUX_IRDA_H",
#ifdef HAVE_LINUX_IRDA_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ISDN_H",
#ifdef HAVE_LINUX_ISDN_H
1
#else
0
#endif
},
{ "HAVE_LINUX_ISDN_PPP_H",
#ifdef HAVE_LINUX_ISDN_PPP_H
1
#else
0
#endif
},
{ "HAVE_LINUX_IVTVFB_H",
#ifdef HAVE_LINUX_IVTVFB_H
1
#else
0
#endif
},
{ "HAVE_LINUX_JOYSTICK_H",
#ifdef HAVE_LINUX_JOYSTICK_H
1
#else
0
#endif
},
{ "HAVE_LINUX_KDEV_T_H",
#ifdef HAVE_LINUX_KDEV_T_H
1
#else
0
#endif
},
{ "HAVE_LINUX_KD_H",
#ifdef HAVE_LINUX_KD_H
1
#else
0
#endif
},
{ "HAVE_LINUX_KVM_H",
#ifdef HAVE_LINUX_KVM_H
1
#else
0
#endif
},
{ "HAVE_LINUX_LP_H",
#ifdef HAVE_LINUX_LP_H
1
#else
0
#endif
},
{ "HAVE_LINUX_MAJOR_H",
#ifdef HAVE_LINUX_MAJOR_H
1
#else
0
#endif
},
{ "HAVE_LINUX_MATROXFB_H",
#ifdef HAVE_LINUX_MATROXFB_H
1
#else
0
#endif
},
{ "HAVE_LINUX_MII_H",
#ifdef HAVE_LINUX_MII_H
1
#else
0
#endif
},
{ "HAVE_LINUX_MMTIMER_H",
#ifdef HAVE_LINUX_MMTIMER_H
1
#else
0
#endif
},
{ "HAVE_LINUX_MSDOS_FS_H",
#ifdef HAVE_LINUX_MSDOS_FS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_MTIO_H",
#ifdef HAVE_LINUX_MTIO_H
1
#else
0
#endif
},
{ "HAVE_LINUX_NBD_H",
#ifdef HAVE_LINUX_NBD_H
1
#else
0
#endif
},
{ "HAVE_LINUX_NCP_FS_H",
#ifdef HAVE_LINUX_NCP_FS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_NETLINK_H",
#ifdef HAVE_LINUX_NETLINK_H
1
#else
0
#endif
},
{ "HAVE_LINUX_NET_TSTAMP_H",
#ifdef HAVE_LINUX_NET_TSTAMP_H
1
#else
0
#endif
},
{ "HAVE_LINUX_NVRAM_H",
#ifdef HAVE_LINUX_NVRAM_H
1
#else
0
#endif
},
{ "HAVE_LINUX_PHANTOM_H",
#ifdef HAVE_LINUX_PHANTOM_H
1
#else
0
#endif
},
{ "HAVE_LINUX_PMU_H",
#ifdef HAVE_LINUX_PMU_H
1
#else
0
#endif
},
{ "HAVE_LINUX_PPDEV_H",
#ifdef HAVE_LINUX_PPDEV_H
1
#else
0
#endif
},
{ "HAVE_LINUX_PPP_COMP_H",
#ifdef HAVE_LINUX_PPP_COMP_H
1
#else
0
#endif
},
{ "HAVE_LINUX_PPP_DEFS_H",
#ifdef HAVE_LINUX_PPP_DEFS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_RADEONFB_H",
#ifdef HAVE_LINUX_RADEONFB_H
1
#else
0
#endif
},
{ "HAVE_LINUX_RANDOM_H",
#ifdef HAVE_LINUX_RANDOM_H
1
#else
0
#endif
},
{ "HAVE_LINUX_RAW_H",
#ifdef HAVE_LINUX_RAW_H
1
#else
0
#endif
},
{ "HAVE_LINUX_REISERFS_FS_H",
#ifdef HAVE_LINUX_REISERFS_FS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_RTC_H",
#ifdef HAVE_LINUX_RTC_H
1
#else
0
#endif
},
{ "HAVE_LINUX_SCC_H",
#ifdef HAVE_LINUX_SCC_H
1
#else
0
#endif
},
{ "HAVE_LINUX_SERIAL_H",
#ifdef HAVE_LINUX_SERIAL_H
1
#else
0
#endif
},
{ "HAVE_LINUX_SERIO_H",
#ifdef HAVE_LINUX_SERIO_H
1
#else
0
#endif
},
{ "HAVE_LINUX_SMB_FS_H",
#ifdef HAVE_LINUX_SMB_FS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_SOCKET_H",
#ifdef HAVE_LINUX_SOCKET_H
1
#else
0
#endif
},
{ "HAVE_LINUX_SOCKIOS_H",
#ifdef HAVE_LINUX_SOCKIOS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_SONET_H",
#ifdef HAVE_LINUX_SONET_H
1
#else
0
#endif
},
{ "HAVE_LINUX_SONYPI_H",
#ifdef HAVE_LINUX_SONYPI_H
1
#else
0
#endif
},
{ "HAVE_LINUX_SPI_SPIDEV_H",
#ifdef HAVE_LINUX_SPI_SPIDEV_H
1
#else
0
#endif
},
{ "HAVE_LINUX_SUSPEND_IOCTLS_H",
#ifdef HAVE_LINUX_SUSPEND_IOCTLS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_SYNCLINK_H",
#ifdef HAVE_LINUX_SYNCLINK_H
1
#else
0
#endif
},
{ "HAVE_LINUX_TERMIOS_H",
#ifdef HAVE_LINUX_TERMIOS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_TIOCL_H",
#ifdef HAVE_LINUX_TIOCL_H
1
#else
0
#endif
},
{ "HAVE_LINUX_TYPES_H",
#ifdef HAVE_LINUX_TYPES_H
1
#else
0
#endif
},
{ "HAVE_LINUX_UDF_FS_I_H",
#ifdef HAVE_LINUX_UDF_FS_I_H
1
#else
0
#endif
},
{ "HAVE_LINUX_UINPUT_H",
#ifdef HAVE_LINUX_UINPUT_H
1
#else
0
#endif
},
{ "HAVE_LINUX_USBDEVICE_FS_H",
#ifdef HAVE_LINUX_USBDEVICE_FS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_USB_GADGETFS_H",
#ifdef HAVE_LINUX_USB_GADGETFS_H
1
#else
0
#endif
},
{ "HAVE_LINUX_USB_G_PRINTER_H",
#ifdef HAVE_LINUX_USB_G_PRINTER_H
1
#else
0
#endif
},
{ "HAVE_LINUX_VIDEODEV2_H",
#ifdef HAVE_LINUX_VIDEODEV2_H
1
#else
0
#endif
},
{ "HAVE_LINUX_VIDEODEV_H",
#ifdef HAVE_LINUX_VIDEODEV_H
1
#else
0
#endif
},
{ "HAVE_LINUX_VIDEO_DECODER_H",
#ifdef HAVE_LINUX_VIDEO_DECODER_H
1
#else
0
#endif
},
{ "HAVE_LINUX_VIDEO_ENCODER_H",
#ifdef HAVE_LINUX_VIDEO_ENCODER_H
1
#else
0
#endif
},
{ "HAVE_LINUX_VT_H",
#ifdef HAVE_LINUX_VT_H
1
#else
0
#endif
},
{ "HAVE_LINUX_WATCHDOG_H",
#ifdef HAVE_LINUX_WATCHDOG_H
1
#else
0
#endif
},
{ "HAVE_LINUX_X25_H",
#ifdef HAVE_LINUX_X25_H
1
#else
0
#endif
},
{ "HAVE_LOCALE_GEN_PROG",
#ifdef HAVE_LOCALE_GEN_PROG
1
#else
0
#endif
},
{ "HAVE_LOCALE_PROG",
#ifdef HAVE_LOCALE_PROG
1
#else
0
#endif
},
{ "HAVE_LOFF_T",
#ifdef HAVE_LOFF_T
1
#else
0
#endif
},
{ "HAVE_LONG_FILE_NAMES",
#ifdef HAVE_LONG_FILE_NAMES
1
#else
0
#endif
},
{ "HAVE_MBRTOWC",
#ifdef HAVE_MBRTOWC
1
#else
0
#endif
},
{ "HAVE_MEMORY_H",
#ifdef HAVE_MEMORY_H
1
#else
0
#endif
},
{ "HAVE_MINCORE",
#ifdef HAVE_MINCORE
1
#else
0
#endif
},
{ "HAVE_MKDTEMP",
#ifdef HAVE_MKDTEMP
1
#else
0
#endif
},
{ "HAVE_MKOSTEMP",
#ifdef HAVE_MKOSTEMP
1
#else
0
#endif
},
{ "HAVE_MMAP",
#ifdef HAVE_MMAP
1
#else
0
#endif
},
{ "HAVE_MNTENT_H",
#ifdef HAVE_MNTENT_H
1
#else
0
#endif
},
{ "HAVE_MUNMAP",
#ifdef HAVE_MUNMAP
1
#else
0
#endif
},
{ "HAVE_NDIR_H",
#ifdef HAVE_NDIR_H
1
#else
0
#endif
},
{ "HAVE_NETASH_ASH_H",
#ifdef HAVE_NETASH_ASH_H
1
#else
0
#endif
},
{ "HAVE_NETAX25_AX25_H",
#ifdef HAVE_NETAX25_AX25_H
1
#else
0
#endif
},
{ "HAVE_NETDB_H",
#ifdef HAVE_NETDB_H
1
#else
0
#endif
},
{ "HAVE_NETECONET_EC_H",
#ifdef HAVE_NETECONET_EC_H
1
#else
0
#endif
},
{ "HAVE_NETINET_IN_H",
#ifdef HAVE_NETINET_IN_H
1
#else
0
#endif
},
{ "HAVE_NETINET_IN_VAR_H",
#ifdef HAVE_NETINET_IN_VAR_H
1
#else
0
#endif
},
{ "HAVE_NETIPX_IPX_H",
#ifdef HAVE_NETIPX_IPX_H
1
#else
0
#endif
},
{ "HAVE_NETIUCV_IUCV_H",
#ifdef HAVE_NETIUCV_IUCV_H
1
#else
0
#endif
},
{ "HAVE_NETPACKET_PACKET_H",
#ifdef HAVE_NETPACKET_PACKET_H
1
#else
0
#endif
},
{ "HAVE_NETROM_NETROM_H",
#ifdef HAVE_NETROM_NETROM_H
1
#else
0
#endif
},
{ "HAVE_NETROSE_ROSE_H",
#ifdef HAVE_NETROSE_ROSE_H
1
#else
0
#endif
},
{ "HAVE_NET_ETHERNET_H",
#ifdef HAVE_NET_ETHERNET_H
1
#else
0
#endif
},
{ "HAVE_NET_IF_ARP_H",
#ifdef HAVE_NET_IF_ARP_H
1
#else
0
#endif
},
{ "HAVE_NET_IF_H",
#ifdef HAVE_NET_IF_H
1
#else
0
#endif
},
{ "HAVE_NET_IF_PPP_H",
#ifdef HAVE_NET_IF_PPP_H
1
#else
0
#endif
},
{ "HAVE_NET_IF_VAR_H",
#ifdef HAVE_NET_IF_VAR_H
1
#else
0
#endif
},
{ "HAVE_NET_PPP_COMP_H",
#ifdef HAVE_NET_PPP_COMP_H
1
#else
0
#endif
},
{ "HAVE_NET_PPP_DEFS_H",
#ifdef HAVE_NET_PPP_DEFS_H
1
#else
0
#endif
},
{ "HAVE_NET_ROUTE_H",
#ifdef HAVE_NET_ROUTE_H
1
#else
0
#endif
},
{ "HAVE_ON_EXIT",
#ifdef HAVE_ON_EXIT
1
#else
0
#endif
},
{ "HAVE_POLL",
#ifdef HAVE_POLL
1
#else
0
#endif
},
{ "HAVE_POLL_H",
#ifdef HAVE_POLL_H
1
#else
0
#endif
},
{ "HAVE_PTRACE",
#ifdef HAVE_PTRACE
1
#else
0
#endif
},
{ "HAVE_PUTENV",
#ifdef HAVE_PUTENV
1
#else
0
#endif
},
{ "HAVE_PWD_H",
#ifdef HAVE_PWD_H
1
#else
0
#endif
},
{ "HAVE_READV",
#ifdef HAVE_READV
1
#else
0
#endif
},
{ "HAVE_REGEX_H",
#ifdef HAVE_REGEX_H
1
#else
0
#endif
},
{ "HAVE_REMOVE",
#ifdef HAVE_REMOVE
1
#else
0
#endif
},
{ "HAVE_SETDOMAINNAME",
#ifdef HAVE_SETDOMAINNAME
1
#else
0
#endif
},
{ "HAVE_SETENV",
#ifdef HAVE_SETENV
1
#else
0
#endif
},
{ "HAVE_SETLOCALE",
#ifdef HAVE_SETLOCALE
1
#else
0
#endif
},
{ "HAVE_SETMNTENT",
#ifdef HAVE_SETMNTENT
1
#else
0
#endif
},
{ "HAVE_SETSID",
#ifdef HAVE_SETSID
1
#else
0
#endif
},
{ "HAVE_SHMAT",
#ifdef HAVE_SHMAT
1
#else
0
#endif
},
{ "HAVE_SHMCTL",
#ifdef HAVE_SHMCTL
1
#else
0
#endif
},
{ "HAVE_SIGNALFD",
#ifdef HAVE_SIGNALFD
1
#else
0
#endif
},
{ "HAVE_SIGSET_T",
#ifdef HAVE_SIGSET_T
1
#else
0
#endif
},
{ "HAVE_SNPRINTF",
#ifdef HAVE_SNPRINTF
1
#else
0
#endif
},
{ "HAVE_STATFS",
#ifdef HAVE_STATFS
1
#else
0
#endif
},
{ "HAVE_STDDEF_H",
#ifdef HAVE_STDDEF_H
1
#else
0
#endif
},
{ "HAVE_STDINT_H",
#ifdef HAVE_STDINT_H
1
#else
0
#endif
},
{ "HAVE_STDIO_EXT_H",
#ifdef HAVE_STDIO_EXT_H
1
#else
0
#endif
},
{ "HAVE_STDLIB_H",
#ifdef HAVE_STDLIB_H
1
#else
0
#endif
},
{ "HAVE_STIME",
#ifdef HAVE_STIME
1
#else
0
#endif
},
{ "HAVE_STRCASECMP",
#ifdef HAVE_STRCASECMP
1
#else
0
#endif
},
{ "HAVE_STRERROR",
#ifdef HAVE_STRERROR
1
#else
0
#endif
},
{ "HAVE_STRERROR_R",
#ifdef HAVE_STRERROR_R
1
#else
0
#endif
},
{ "HAVE_STRINGS_H",
#ifdef HAVE_STRINGS_H
1
#else
0
#endif
},
{ "HAVE_STRING_H",
#ifdef HAVE_STRING_H
1
#else
0
#endif
},
{ "HAVE_STRNCASECMP",
#ifdef HAVE_STRNCASECMP
1
#else
0
#endif
},
{ "HAVE_STRNDUP",
#ifdef HAVE_STRNDUP
1
#else
0
#endif
},
{ "HAVE_STRNSTR",
#ifdef HAVE_STRNSTR
1
#else
0
#endif
},
{ "HAVE_STRSIGNAL",
#ifdef HAVE_STRSIGNAL
1
#else
0
#endif
},
{ "HAVE_STRTOF",
#ifdef HAVE_STRTOF
1
#else
0
#endif
},
{ "HAVE_STRTOLD",
#ifdef HAVE_STRTOLD
1
#else
0
#endif
},
{ "HAVE_STRUCT_IFCONF",
#ifdef HAVE_STRUCT_IFCONF
1
#else
0
#endif
},
{ "HAVE_STRUCT_SERIAL_RS485",
#ifdef HAVE_STRUCT_SERIAL_RS485
1
#else
0
#endif
},
{ "HAVE_STRUCT_SERIAL_RS485_delay_rts_after_send",
#ifdef HAVE_STRUCT_SERIAL_RS485_delay_rts_after_send
1
#else
0
#endif
},
{ "HAVE_SYSLOG_H",
#ifdef HAVE_SYSLOG_H
1
#else
0
#endif
},
{ "HAVE_SYS_CAPABILITY_H",
#ifdef HAVE_SYS_CAPABILITY_H
1
#else
0
#endif
},
{ "HAVE_SYS_DIR_H",
#ifdef HAVE_SYS_DIR_H
1
#else
0
#endif
},
{ "HAVE_SYS_EVENTFD_H",
#ifdef HAVE_SYS_EVENTFD_H
1
#else
0
#endif
},
{ "HAVE_SYS_FILE_H",
#ifdef HAVE_SYS_FILE_H
1
#else
0
#endif
},
{ "HAVE_SYS_FILIO_H",
#ifdef HAVE_SYS_FILIO_H
1
#else
0
#endif
},
{ "HAVE_SYS_IOCCOM_H",
#ifdef HAVE_SYS_IOCCOM_H
1
#else
0
#endif
},
{ "HAVE_SYS_IOCTL_H",
#ifdef HAVE_SYS_IOCTL_H
1
#else
0
#endif
},
{ "HAVE_SYS_MMAN_H",
#ifdef HAVE_SYS_MMAN_H
1
#else
0
#endif
},
{ "HAVE_SYS_MNTENT_H",
#ifdef HAVE_SYS_MNTENT_H
1
#else
0
#endif
},
{ "HAVE_SYS_MNTTAB_H",
#ifdef HAVE_SYS_MNTTAB_H
1
#else
0
#endif
},
{ "HAVE_SYS_MOUNT_H",
#ifdef HAVE_SYS_MOUNT_H
1
#else
0
#endif
},
{ "HAVE_SYS_MTIO_H",
#ifdef HAVE_SYS_MTIO_H
1
#else
0
#endif
},
{ "HAVE_SYS_NDIR_H",
#ifdef HAVE_SYS_NDIR_H
1
#else
0
#endif
},
{ "HAVE_SYS_PARAM_H",
#ifdef HAVE_SYS_PARAM_H
1
#else
0
#endif
},
{ "HAVE_SYS_PTRACE_H",
#ifdef HAVE_SYS_PTRACE_H
1
#else
0
#endif
},
{ "HAVE_SYS_RAW_H",
#ifdef HAVE_SYS_RAW_H
1
#else
0
#endif
},
{ "HAVE_SYS_RESOURCE_H",
#ifdef HAVE_SYS_RESOURCE_H
1
#else
0
#endif
},
{ "HAVE_SYS_SELECT_H",
#ifdef HAVE_SYS_SELECT_H
1
#else
0
#endif
},
{ "HAVE_SYS_SHM_H",
#ifdef HAVE_SYS_SHM_H
1
#else
0
#endif
},
{ "HAVE_SYS_SIGNALFD_H",
#ifdef HAVE_SYS_SIGNALFD_H
1
#else
0
#endif
},
{ "HAVE_SYS_SOCKET_H",
#ifdef HAVE_SYS_SOCKET_H
1
#else
0
#endif
},
{ "HAVE_SYS_SOCKIO_H",
#ifdef HAVE_SYS_SOCKIO_H
1
#else
0
#endif
},
{ "HAVE_SYS_STATFS_H",
#ifdef HAVE_SYS_STATFS_H
1
#else
0
#endif
},
{ "HAVE_SYS_STATVFS_H",
#ifdef HAVE_SYS_STATVFS_H
1
#else
0
#endif
},
{ "HAVE_SYS_STAT_H",
#ifdef HAVE_SYS_STAT_H
1
#else
0
#endif
},
{ "HAVE_SYS_SYSMACROS_H",
#ifdef HAVE_SYS_SYSMACROS_H
1
#else
0
#endif
},
{ "HAVE_SYS_TERMIOS_H",
#ifdef HAVE_SYS_TERMIOS_H
1
#else
0
#endif
},
{ "HAVE_SYS_TERMIO_H",
#ifdef HAVE_SYS_TERMIO_H
1
#else
0
#endif
},
{ "HAVE_SYS_TIMEB_H",
#ifdef HAVE_SYS_TIMEB_H
1
#else
0
#endif
},
{ "HAVE_SYS_TIMERFD_H",
#ifdef HAVE_SYS_TIMERFD_H
1
#else
0
#endif
},
{ "HAVE_SYS_TIMEX_H",
#ifdef HAVE_SYS_TIMEX_H
1
#else
0
#endif
},
{ "HAVE_SYS_TIME_H",
#ifdef HAVE_SYS_TIME_H
1
#else
0
#endif
},
{ "HAVE_SYS_TTYCOM_H",
#ifdef HAVE_SYS_TTYCOM_H
1
#else
0
#endif
},
{ "HAVE_SYS_TYPES_H",
#ifdef HAVE_SYS_TYPES_H
1
#else
0
#endif
},
{ "HAVE_SYS_UIO_H",
#ifdef HAVE_SYS_UIO_H
1
#else
0
#endif
},
{ "HAVE_SYS_UN_H",
#ifdef HAVE_SYS_UN_H
1
#else
0
#endif
},
{ "HAVE_SYS_USER_H",
#ifdef HAVE_SYS_USER_H
1
#else
0
#endif
},
{ "HAVE_SYS_USTAT_H",
#ifdef HAVE_SYS_USTAT_H
1
#else
0
#endif
},
{ "HAVE_SYS_VFS_H",
#ifdef HAVE_SYS_VFS_H
1
#else
0
#endif
},
{ "HAVE_SYS_WAIT_H",
#ifdef HAVE_SYS_WAIT_H
1
#else
0
#endif
},
{ "HAVE_TCDRAIN",
#ifdef HAVE_TCDRAIN
1
#else
0
#endif
},
{ "HAVE_TCFLOW",
#ifdef HAVE_TCFLOW
1
#else
0
#endif
},
{ "HAVE_TCFLUSH",
#ifdef HAVE_TCFLUSH
1
#else
0
#endif
},
{ "HAVE_TCGETATTR",
#ifdef HAVE_TCGETATTR
1
#else
0
#endif
},
{ "HAVE_TCSENDBREAK",
#ifdef HAVE_TCSENDBREAK
1
#else
0
#endif
},
{ "HAVE_TCSETATTR",
#ifdef HAVE_TCSETATTR
1
#else
0
#endif
},
{ "HAVE_TERMIOS_H",
#ifdef HAVE_TERMIOS_H
1
#else
0
#endif
},
{ "HAVE_TERMIO_H",
#ifdef HAVE_TERMIO_H
1
#else
0
#endif
},
{ "HAVE_TIMERFD_CREATE",
#ifdef HAVE_TIMERFD_CREATE
1
#else
0
#endif
},
{ "HAVE_TIME_H",
#ifdef HAVE_TIME_H
1
#else
0
#endif
},
{ "HAVE_UNISTD_H",
#ifdef HAVE_UNISTD_H
1
#else
0
#endif
},
{ "HAVE_UNSETENV",
#ifdef HAVE_UNSETENV
1
#else
0
#endif
},
{ "HAVE_USTAT",
#ifdef HAVE_USTAT
1
#else
0
#endif
},
{ "HAVE_USTAT_H",
#ifdef HAVE_USTAT_H
1
#else
0
#endif
},
{ "HAVE_UTIMES",
#ifdef HAVE_UTIMES
1
#else
0
#endif
},
{ "HAVE_UTIME_H",
#ifdef HAVE_UTIME_H
1
#else
0
#endif
},
{ "HAVE_V4L2_CTRL_TYPE_STRING",
#ifdef HAVE_V4L2_CTRL_TYPE_STRING
1
#else
0
#endif
},
{ "HAVE_V4L2_DBG_REGISTER",
#ifdef HAVE_V4L2_DBG_REGISTER
1
#else
0
#endif
},
{ "HAVE_VSNPRINTF",
#ifdef HAVE_VSNPRINTF
1
#else
0
#endif
},
{ "HAVE_WCHAR_H",
#ifdef HAVE_WCHAR_H
1
#else
0
#endif
},
{ "HAVE_WCTYPE_H",
#ifdef HAVE_WCTYPE_H
1
#else
0
#endif
},
{ "HAVE_WCWIDTH",
#ifdef HAVE_WCWIDTH
1
#else
0
#endif
},
{ "HAVE_WRITEV",
#ifdef HAVE_WRITEV
1
#else
0
#endif
},
{ "HAVE__G_CONFIG_H",
#ifdef HAVE__G_CONFIG_H
1
#else
0
#endif
},
{ "HAVE___FPURGE",
#ifdef HAVE___FPURGE
1
#else
0
#endif
},
{ "HAVE_v4l2_hw_freq_seek_spacing",
#ifdef HAVE_v4l2_hw_freq_seek_spacing
1
#else
0
#endif
},
{ "LINUX_TYPES_H_STRUCT_USTAT",
#ifdef LINUX_TYPES_H_STRUCT_USTAT
1
#else
0
#endif
},
{ "NET_IF_LINUX_IF_PLAY_NICE",
#ifdef NET_IF_LINUX_IF_PLAY_NICE
1
#else
0
#endif
},
{ "PACKAGE_BUGREPORT",
#ifdef PACKAGE_BUGREPORT
1
#else
0
#endif
},
{ "PACKAGE_NAME",
#ifdef PACKAGE_NAME
1
#else
0
#endif
},
{ "PACKAGE_STRING",
#ifdef PACKAGE_STRING
1
#else
0
#endif
},
{ "PACKAGE_TARNAME",
#ifdef PACKAGE_TARNAME
1
#else
0
#endif
},
{ "PACKAGE_URL",
#ifdef PACKAGE_URL
1
#else
0
#endif
},
{ "PACKAGE_VERSION",
#ifdef PACKAGE_VERSION
1
#else
0
#endif
},
{ "PROC_PID_CMDLINE",
#ifdef PROC_PID_CMDLINE
1
#else
0
#endif
},
{ "PROC_PID_CWD",
#ifdef PROC_PID_CWD
1
#else
0
#endif
},
{ "PROC_PID_EXE",
#ifdef PROC_PID_EXE
1
#else
0
#endif
},
{ "PROC_PID_FD_N",
#ifdef PROC_PID_FD_N
1
#else
0
#endif
},
{ "PROC_PID_PATH_A_OUT",
#ifdef PROC_PID_PATH_A_OUT
1
#else
0
#endif
},
{ "PROC_PID_PATH_CWD",
#ifdef PROC_PID_PATH_CWD
1
#else
0
#endif
},
{ "PROC_PID_PATH_N",
#ifdef PROC_PID_PATH_N
1
#else
0
#endif
},
{ "PROC_PID_PATH_ROOT",
#ifdef PROC_PID_PATH_ROOT
1
#else
0
#endif
},
{ "PROC_PID_ROOT",
#ifdef PROC_PID_ROOT
1
#else
0
#endif
},
{ "PROC_SELF",
#ifdef PROC_SELF
1
#else
0
#endif
},
{ "RETSIGTYPE",
#ifdef RETSIGTYPE
1
#else
0
#endif
},
{ "SETPGRP_NARGS",
#ifdef SETPGRP_NARGS
1
#else
0
#endif
},
{ "SIZEOF_INT",
#ifdef SIZEOF_INT
1
#else
0
#endif
},
{ "SIZEOF_LONG",
#ifdef SIZEOF_LONG
1
#else
0
#endif
},
{ "SIZEOF_LONG_LONG",
#ifdef SIZEOF_LONG_LONG
1
#else
0
#endif
},
{ "SIZEOF_OFF_T",
#ifdef SIZEOF_OFF_T
1
#else
0
#endif
},
{ "SIZEOF_PTRDIFF_T",
#ifdef SIZEOF_PTRDIFF_T
1
#else
0
#endif
},
{ "SIZEOF_SIZE_T",
#ifdef SIZEOF_SIZE_T
1
#else
0
#endif
},
{ "SIZEOF_SSIZE_T",
#ifdef SIZEOF_SSIZE_T
1
#else
0
#endif
},
{ "SIZEOF_VOID_P",
#ifdef SIZEOF_VOID_P
1
#else
0
#endif
},
{ "STATFS_NARGS",
#ifdef STATFS_NARGS
1
#else
0
#endif
},
{ "STDC_HEADERS",
#ifdef STDC_HEADERS
1
#else
0
#endif
},
{ "STRERROR_R_CHAR_P",
#ifdef STRERROR_R_CHAR_P
1
#else
0
#endif
},
{ "SYS_PTRACE_USER_REGS_STRUCT",
#ifdef SYS_PTRACE_USER_REGS_STRUCT
1
#else
0
#endif
},
{ "TIME_WITH_SYS_TIME",
#ifdef TIME_WITH_SYS_TIME
1
#else
0
#endif
},
{ "V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE",
#ifdef V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
1
#else
0
#endif
},
{ "V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE",
#ifdef V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE
1
#else
0
#endif
},
{ "VA_LIST_VOID_STAR",
#ifdef VA_LIST_VOID_STAR
1
#else
0
#endif
},
{ "_FILE_OFFSET_BITS",
#ifdef _FILE_OFFSET_BITS
1
#else
0
#endif
},
{ "_LARGEFILE_SOURCE",
#ifdef _LARGEFILE_SOURCE
1
#else
0
#endif
},
{ "_LARGE_FILES",
#ifdef _LARGE_FILES
1
#else
0
#endif
},
{ "_MINIX",
#ifdef _MINIX
1
#else
0
#endif
},
{ "_PATH_MNTTAB",
#ifdef _PATH_MNTTAB
1
#else
0
#endif
},
{ "_PATH_MOUNTED",
#ifdef _PATH_MOUNTED
1
#else
0
#endif
},
{ "_POSIX_1_SOURCE",
#ifdef _POSIX_1_SOURCE
1
#else
0
#endif
},
{ "_POSIX_SOURCE",
#ifdef _POSIX_SOURCE
1
#else
0
#endif
},
{ "const",
#ifdef const
1
#else
0
#endif
},
{ "inline",
#ifdef inline
1
#else
0
#endif
},
{ "size_t",
#ifdef size_t
1
#else
0
#endif
},
